@@ -5,7 +5,7 @@
 ;; Author: Oscar Figueiredo <oscar@xemacs.org>
 ;; Maintainer: Oscar Figueiredo <oscar@xemacs.org>
 ;; Created: Feb 1998
-;; Version: $Revision: 1.19 $
+;; Version: $Revision: 1.20 $
 ;; Keywords: help
 
 ;; This file is part of XEmacs
@@ -149,7 +149,7 @@ one of the properties on the list."
   "Extract a value from a lax property list.
 
 LAX-PLIST is a lax property list, which is a list of the form (PROP1
-VALUE1 PROP2 VALUE2...), where comparions between properties is done
+VALUE1 PROP2 VALUE2...), where comparison between properties is done
 using `equal' instead of `eq'.  This function returns the value
 corresponding to the given PROP, or DEFAULT if PROP is not one of the
 properties on the list."
@@ -620,7 +620,7 @@ otherwise they are formatted according to `eudc-user-attribute-names-alist'."
       result)))
 
 (defun eudc-filter-partial-records (records attrs)
-  "Eliminate records that do not caontain all ATTRS from RECORDS."
+  "Eliminate records that do not contain all ATTRS from RECORDS."
   (delq nil 
 	(mapcar 
 	 (function 
